# last_watched_series
A simple command-line application for memorizing the last watched series.

# Installation

### 1. Using Pip
```bash
  $ pip install last_watched_series
```

### 2. Manual
```bash
  $ git clone https://github.com/Qyutou/last_watched_series.git
  $ cd last_watched_series
  $ python setup.py install
```

# Usage
Next command will show all possible commands:
```bash
  $  last_watched_series
```
